package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````W!\```````!``````````'@!`0``
M`````````$``.``)`$``%P`6``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````/2:````````])H`````````
M``$```````$````&````F/L```````"8^P$``````)C[`0``````Z`0`````
M``!`!0```````````0```````@````8```"H^P```````*C[`0``````J/L!
M``````#@`0```````.`!````````"``````````$````!````%0"````````
M5`(```````!4`@```````"0`````````)``````````$`````````%#E=&0$
M````X),```````#@DP```````."3````````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````)C[````````F/L!``````"8^P$`
M`````&@$````````:`0````````!`````````"]L:6(O;&0M;75S;"UA87)C
M:#8T+G-O+C$````$````%`````,```!'3E4`PX\!E2R0ZSKLRTA_W;#^PC-P
MIT(1````2P````0````(````(1`0``7`!(`H`!`%@(9`A(*A``8)``2)B(`8
M0;H$`@A+````3````%````!5````5@```%X```!?````8`````````!B````
M8P````````!D````90```&@```````````````&O-.C.WD<M;L7?'VI_FGSK
MT^\.+L6;MG94/)2XC?$.(/_D#M5DU'S9<5@<L@&+;YA/PYO"Y3\L0OK7A_JA
M;&!8[Y=YNN.2?.-'Q@%5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_J9R;OMI7
M&^"G`@IK&IY0H^#[20``````````````````````````````````````````
M`P`(`/`9`````````````````````````P`3`````@````````````````"6
M`@``$@````````````````````````"[`0``$@``````````````````````
M``!9````$@````````````````````````#<`@``$@``````````````````
M``````#!````$0````````````````````````"/`0``$@``````````````
M```````````]````$@`````````````````````````Y`0``$@``````````
M``````````````#^`0``$@````````````````````````"X````$@``````
M``````````````````#3````(@````````````````````````!8`0``$@``
M``````````````````````#C`0``$@````````````````````````"$`@``
M$@````````````````````````"@`0``$@`````````````````````````<
M`0``$@````````````````````````"=`@``$@``````````````````````
M``#G`@``(0`````````````````````````W````$@``````````````````
M``````#F`@``$0````````````````````````#6`0``$0``````````````
M``````````!'`0``$@````````````````````````!M`@``$@``````````
M``````````````!I````$@`````````````````````````=`@``$@``````
M``````````````````#H`@``$0````````````````````````"I````$@``
M``````````````````````!$`@``$@`````````````````````````?````
M(`````````````````````````!M`0``$@````````````````````````#]
M````(`````````````````````````#E`@``(0``````````````````````
M``!Q````$@````````````````````````"A````$@``````````````````
M```````7`0``$@````````````````````````!A````$@``````````````
M``````````!2````$@`````````````````````````0````$@``````````
M```````````````[`@``$@````````````````````````"T`@``$@``````
M``````````````````"O`0``$@````````````````````````"`````(```
M``````````````````````"M`@``$@````````````````````````!=`@``
M$@````````````````````````!+````$@`````````````````````````*
M`@``$@`````````````````````````!````$@``````````````````````
M``!$````$@`````````````````````````U!```$@``````````````````
M``````!/`@``$@````````````````````````"E`@``$@``````````````
M```````````)````$0`````````````````````````K`@``$@``````````
M``````````````!R````$@````````````````````````"+`@``$@``````
M```````````````````8````$@`````````````````````````B`0``$@``
M``````````````````````#X````$@````````````````````````!\`0``
M%@````````````````````````"[`@``$@````````````````````````#*
M`@``$@````````````````````````!``0``$@``````````````````````
M``"<````$@````````````````````````"Q````$@``````````````````
M``````!W````$@````````````````````````!?`0``$@``````````````
M``````````!X`@``$@`````````````````````````S`0``$@``````````
M``````````````#B````(`````````````````````````#T`0``$@``````
M``````````````````"H````$@````````````````````````#Y`0``$@``
M``````````````````````"6`P``$``4`-@``@````````````````"U`P``
M$@`*`+0T````````_`4```````#"`P``$@`*`/`\````````^`````````#7
M`@``$@`*`-`=````````#`(```````#0`0``$@`+`#A2````````!```````
M```?`P``$@`*`"`H````````!``````````P`P``$``4`(```@``````````
M``````!!!```$@`(`/`9````````!`````````!B`P``$@`*`"0H````````
M6`(```````!W`P``$@`*`+`Z````````0`(```````#.`P``$``4`(```@``
M``````````````!(`P``$@`*`/`P````````>`````````!O`P``$@`*`'`Q
M````````G`````````"-`P``$@`*`,`F````````+`````````"J`P``$@`*
M`/!.````````@`$```````#:`P``$@`*`(0S````````,`$````````"!```
M$``4`-@``@`````````````````1!```$``4`-@``@`````````````````6
M!```$@`*`(`J````````+`````````"A`P``$@`*`/@?````````*```````
M``!6`P``$@`*`+`J````````=`$````````^`P``$0`3`'@``@``````"```
M```````*!```$``3`(```@````````````````#3`P``$@`*`-P?````````
M```````````^!```$@`*`+!.````````0``````````C!```$@`*`&0S````
M````(`````````"5`P``$``4`-@``@````````````````#L`P``$@`*`/`F
M````````,`$```````!'!```$@`*`'!0````````R`$````````2`P``$@`*
M`"0L````````S`0`````````;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E
M<W,`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED`'-T<F-M
M<`!M96US970`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!S=')R8VAR`&QS=&%T
M`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T
M<G-T<@!V9G!R:6YT9@!S=')C:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A
M<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`
M7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?97)R;F]?
M;&]C871I;VX`;6MD:7(`;65M8W!Y`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL
M`&=E='5I9`!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E
M;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%]F:6YI`%!,7V1O7W5N
M9'5M<`!097)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!0
M97)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H
M<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`'-T<F-P>0!R96%D9&ER`'-P<FEN=&8`<W1R9'5P`'-T<G1O:P!P=&AR
M96%D7V%T9F]R:P!?7VQI8F-?<W1A<G1?;6%I;@!S;G!R:6YT9@!?7U]E;G9I
M<F]N`&QI8G!E<FPN<V\`;&EB8RYM=7-L+6%A<F-H-C0N<V\N,0!P87)?:6YI
M=%]E;G8`<&%R7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&UY7W!A<E]P
M;`!P87)?96YV7V-L96%N`'!A<E]D:7)N86UE`'!A<E]F:6YD<')O9P!P87)?
M9&EE`%A37TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET`%]?8G-S7V5N9%]?
M`%]S=&%R=%]C`'-H85]U<&1A=&4`<&%R7VUK=&UP9&ER`'!A<E]C;&5A;G5P
M`%]?8G-S7W-T87)T`'!A<E]S971U<%]L:6)P871H`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!?7V5N9%]?`%]E9&%T80!?96YD`'!A<E]B87-E;F%M90!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!S:&%?:6YI=`!S:&%?9FEN86P`+W5S
M<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``)C[`0```````P0```````#P
M(````````*#[`0```````P0```````"0(````````*#_`0```````P0`````
M``#P&0```````-#_`0```````P0```````#0'0```````.#_`0```````P0`
M```````X4@```````````@```````P0```````````(``````!@``@``````
M`P0````````85@```````"```@```````P0```````"H4@```````#```@``
M`````P0```````"84P```````#@``@```````P0```````#X50```````$``
M`@```````P0`````````5@```````$@``@```````P0````````(5@``````
M`%```@```````P0````````05@```````&```@```````P0```````#@50``
M`````&@``@```````P0```````#H50```````'@``@```````P0````````@
M5@```````(#_`0```````00```<``````````````(C_`0```````00```@`
M`````````````)#_`0```````00```T``````````````)C_`0```````00`
M`!<``````````````*C_`0```````00``!P``````````````+#_`0``````
M`00``!\``````````````+C_`0```````00``"$``````````````,#_`0``
M`````00``"P``````````````,C_`0```````00``"X``````````````-C_
M`0```````00``#```````````````.C_`0```````00``#8`````````````
M`/#_`0``````!@0``#T``````````````/C_`0```````00``$<`````````
M`````*#]`0```````@0```,``````````````*C]`0```````@0```0`````
M`````````+#]`0```````@0```4``````````````+C]`0```````@0```8`
M`````````````,#]`0```````@0```D``````````````,C]`0```````@0`
M``H``````````````-#]`0```````@0```L``````````````-C]`0``````
M`@0```P``````````````.#]`0```````@0```T``````````````.C]`0``
M`````@0```X``````````````/#]`0```````@0```\``````````````/C]
M`0```````@0``!````````````````#^`0```````@0``!$`````````````
M``C^`0```````@0``!(``````````````!#^`0```````@0``!,`````````
M`````!C^`0```````@0``!4``````````````"#^`0```````@0``!@`````
M`````````"C^`0```````@0``!D``````````````##^`0```````@0``!H`
M`````````````#C^`0```````@0``!L``````````````$#^`0```````@0`
M`!T``````````````$C^`0```````@0``!X``````````````%#^`0``````
M`@0``!\``````````````%C^`0```````@0``"```````````````&#^`0``
M`````@0``",``````````````&C^`0```````@0``"0``````````````'#^
M`0```````@0``"4``````````````'C^`0```````@0``"8`````````````
M`(#^`0```````@0``"<``````````````(C^`0```````@0``"@`````````
M`````)#^`0```````@0``"D``````````````)C^`0```````@0``"H`````
M`````````*#^`0```````@0``"L``````````````*C^`0```````@0``"T`
M`````````````+#^`0```````@0``"\``````````````+C^`0```````@0`
M`#$``````````````,#^`0```````@0``#(``````````````,C^`0``````
M`@0``#,``````````````-#^`0```````@0``#0``````````````-C^`0``
M`````@0``#4``````````````.#^`0```````@0``#<``````````````.C^
M`0```````@0``#@``````````````/#^`0```````@0``#D`````````````
M`/C^`0```````@0``#H```````````````#_`0```````@0``#L`````````
M``````C_`0```````@0``#P``````````````!#_`0```````@0``#X`````
M`````````!C_`0```````@0``#\``````````````"#_`0```````@0``$``
M`````````````"C_`0```````@0``$$``````````````##_`0```````@0`
M`$(``````````````#C_`0```````@0``$,``````````````$#_`0``````
M`@0``$0``````````````$C_`0```````@0``$4``````````````%#_`0``
M`````@0``$8``````````````%C_`0```````@0``$<``````````````&#_
M`0```````@0``$@``````````````&C_`0```````@0``$D`````````````
M`'#_`0```````@0``$H``````````````/U[OZG]`P"1_7O!J,`#7];P>[^I
M\```T!'.1OD08C:1(`(?UA\@`]4?(`/5'R`#U?```-`1TD;Y$((VD2`"'];P
M``#0$=9&^1"B-I$@`A_6\```T!':1OD0PC:1(`(?UO```-`1WD;Y$.(VD2`"
M'];P``#0$>)&^1`"-Y$@`A_6\```T!'F1OD0(C>1(`(?UO```-`1ZD;Y$$(W
MD2`"'];P``#0$>Y&^1!B-Y$@`A_6\```T!'R1OD0@C>1(`(?UO```-`1]D;Y
M$*(WD2`"'];P``#0$?I&^1#"-Y$@`A_6\```T!'^1OD0XC>1(`(?UO```-`1
M`D?Y$`(XD2`"'];P``#0$09'^1`B.)$@`A_6\```T!$*1_D00CB1(`(?UO``
M`-`1#D?Y$&(XD2`"'];P``#0$1)'^1"".)$@`A_6\```T!$61_D0HCB1(`(?
MUO```-`1&D?Y$,(XD2`"'];P``#0$1Y'^1#B.)$@`A_6\```T!$B1_D0`CF1
M(`(?UO```-`1)D?Y$"(YD2`"'];P``#0$2I'^1!".9$@`A_6\```T!$N1_D0
M8CF1(`(?UO```-`1,D?Y$((YD2`"'];P``#0$39'^1"B.9$@`A_6\```T!$Z
M1_D0PCF1(`(?UO```-`1/D?Y$.(YD2`"'];P``#0$4)'^1`".I$@`A_6\```
MT!%&1_D0(CJ1(`(?UO```-`12D?Y$$(ZD2`"'];P``#0$4Y'^1!B.I$@`A_6
M\```T!%21_D0@CJ1(`(?UO```-`15D?Y$*(ZD2`"'];P``#0$5I'^1#".I$@
M`A_6\```T!%>1_D0XCJ1(`(?UO```-`18D?Y$`([D2`"'];P``#0$69'^1`B
M.Y$@`A_6\```T!%J1_D00CN1(`(?UO```-`1;D?Y$&([D2`"'];P``#0$7)'
M^1"".Y$@`A_6\```T!%V1_D0HCN1(`(?UO```-`1>D?Y$,([D2`"'];P``#0
M$7Y'^1#B.Y$@`A_6\```T!&"1_D0`CR1(`(?UO```-`1AD?Y$"(\D2`"'];P
M``#0$8I'^1!"/)$@`A_6\```T!&.1_D08CR1(`(?UO```-`1DD?Y$((\D2`"
M'];P``#0$99'^1"B/)$@`A_6\```T!&:1_D0PCR1(`(?UO```-`1GD?Y$.(\
MD2`"'];P``#0$:)'^1`"/9$@`A_6\```T!&F1_D0(CV1(`(?UO```-`1JD?Y
M$$(]D2`"'];P``#0$:Y'^1!B/9$@`A_6\```T!&R1_D0@CV1(`(?UO```-`1
MMD?Y$*(]D2`"'];P``#0$;I'^1#"/9$@`A_6_X,!T>,``-!CP$?Y_7L#J?W#
M`)'BAP"IXB,`D>%#`)'@'P"YX',`D?-3!*GU6P6I9`!`^>07`/D$`(#28?__
ME^(``-!"[$?YX```T`#$1_GA`P*JM___E^```-``S$?Y``!`.4`)`#;@``#0
M`/A'^4'0.]7S``#P(FA@^/0?0+E!:%(Y@!(`$90.`!$A!``R06@2.0!\?9/"
M__^7XP,`JN8+0/G@``#P8N("D>4?0+D$/$#Y(0``D,<`0/DA0!>1(```D`!@
M%Y%G!`"I0P0`^60``:F_!`!Q#0D`5"$`@-(@#``1Q'AA^"$$`)%DV"#XOP`!
M:VS__U2E#``1=>("D7_8)?@!``"PX@,4*B%0&9$$`(#2H`Y`^1+__Y<`!0`T
M=>("D?:3`)&@#D#Y8?__E_0#`"KA`Q:J(```D`"@#)&(``"4(`0`M'/B`I%@
M#D#YH/__EX___Y?@``#0`,!'^>(70/D!`$#Y0@`!ZP$`@-+!!`!4_7M#J>`#
M%"KS4T2I]5M%J?^#`9'``U_66?__E_,``/!BX@*10`P`^2`#`+3<_O^7X```
MT`#X1_E!T#O5(FA@^%\X)CFP__\7H`Y`^1S__Y?7__\7H`I`^6```+14!P"4
MW?__%^$#%JH@``"0`,`*D5\``)2@"@#YX/K_M$P'`)35__\7A0"`4L#__Q<@
M`(!21___E]+^_Y<=`(#2'@"`TN`#`)'A``#0(:`ND1_L?)(!```4X@,`J@4`
M@-+D``"PA/!'^4&$0/CC``"P8]!'^>```+``Z$?Y/?__%^```-````*1X0``
MT"$``I$_``#KP```5.$``+`AX$?Y80``M/`#`:H``A_6P`-?UN```-````*1
MX0``T"$``I$A``#+(OQ_TT$,@8LA_$&3P0``M.(``+!"W$?Y8@``M/`#`JH`
M`A_6P`-?UA\@`]7]>[ZI_0,`D?,+`/GS``#08`)".0`"`#?@``"P`,A'^8``
M`+3@``#0``!`^7G^_Y?8__^7X```L`#81_F```"T(```\`!@$Y&J_O^7(`"`
M4F`"`CGS"T#Y_7O"J,`#7];@``"P`/Q'^4`!`+3]>[^IX0``T"```/#]`P"1
M(2`"D0!@$Y$?__^7_7O!J,W__Q?,__\7'R`#U1\@`]4?(`/5_7N\J?T#`)'S
M4P&IH`8`M/=C`ZGW`P"JX```L`#41_D8`$#Y.`8`M/5;`JGV`P&J%0"`4N`"
M0#D?]`!Q!!A`>L$"`%03`T#YTP$`M+5^0)/T`QBJ'R`#U>(#%:KA`Q>JX`,3
MJH_^_Y>````U8&IU.!_T`'$``@!4DXY`^//^_[7U6T*I]V-#J>`#$ZKS4T&I
M_7O$J,`#7];U`Q>JH!Y`.!_T`'$$&$!ZH?__5+4"%TOE__\7@`(8R[4&`)%S
M`A6+`/Q#D\`"`+G@`Q.J\U-!J?5;0JGW8T.I_7O$J,`#7]83`(#2Z?__%_=C
M0ZD3`(#2YO__%__#`M'B``"P0L!'^>$C`)']>PFI_4,"D?-3`/GS`P"J0P!`
M^>-'`/D#`(#25/[_ET`"`#7A&T"Y`@"44B$,%!(_$$!Q)!!">L`!`%3A``"P
M(<!'^>-'0/DB`$#Y8P`"ZP(`@-*A`0!4_7M)J?-30/G_PP*1P`-?U@``@%+T
M__\7X`,3JD$`@%*)_O^7'P``<>`7GQKN__\7&?[_E_\#`]'A``"P(<!'^?U[
M":G]0P*1(@!`^>)'`/D"`(#2P```M/-3"JGS`P"J`0!`.8$!`#7S4TJIX```
ML`#`1_GB1T#Y`0!`^4(``>L!`(#2@0@`5/U[2:G_`P.1P`-?UO5;"ZE+_O^7
M]`,`JB`&`+3@`Q2J\_W_ET`%`+0!3$`Y%4P`D3^X`'&!``!4H09`.0'__S0?
M(`/5`$Q`.1^X`''@!`!4X`,3JF[^_Y?V`P"JX`,5JFO^_Y?``@`+``@`$0!\
M0)/3_?^7XP,5JN(#$ZKU`P"J`0``\"%`"9$]_O^7X2,`D>`#%:I"_O^7'P0`
M,:```%3@&T"Y``P4$A\00'&@`@!4X`,5J@;^_Y?@`Q6J?/[_E^`#%*K*_?^7
M`/O_M>`#%*I;_O^7X`,3JL']_Y?S4TJI]5M+J<#__Q>@!D`Y'[@`<0'[_U2@
M"D`Y(/G_--7__Q?@`Q6JJO__E^S__Q?S4PJI]5L+J;[]_Y<?(`/5_X,!T?U[
M`:G]0P"1\U,"J?,#`*KT`P&J]5L#J?=C!*G@``"P`,!'^2$`0#D"`$#YX@<`
M^0(`@-(_]`!QE!:4FN`#%*HK_O^7]@,`JN$3`)'@`Q.J*___ER`(`+3U`P"J
M)/[_E]\"`.OI!@!4]P>`N?@``+`8UT?Y]_)]TV`"0#D?]`!Q!!A`>L`+`%3D
M`Q.J@QQ`.'_T`'%D&$!ZH?__5(0`$\N$?$"3%0-`^<`*`)$```2+>_W_EZ!J
M-_B@`@"T`0-`^>`#$ZHC:'?X`11`.&$``#D_]`!Q)!A`>L```%0"%$`X8AP`
M.%_T`'%$&$!Z@?__5*$'@%(``(#2810`.()J8#AB:"`X``0`D:+__S7@``"P
M`,!'^>('0/D!`$#Y0@`!ZP$`@-)A!P!4_7M!J?-30JGU6T.I]V-$J?^#`9'`
M`U_6`0"`TH)J83BB:B$X(00`D:+__S7N__\7^```L!C71_GY:P6I&@-`^4`#
M0/G`!`"TX`,:JA4`@%(?(`/5`8Q`^.(#%2JU!@`1H?__M4`,`!$`?'V3X0``
MT"*X0+D"`@`U(@"`4B*X`+D]_?^7^0,`JD`#`+2W?GV3X0,:JN(#%ZH3_?^7
M&0,`^:`&`!'U!P"Y/]L@^/EK1:FH__\7X0,`JN`#&JIV_?^7``,`^?D#`*I`
M`0"TMWY]D_3__Q<$`(#2J?__%P`"@-(5`(!2XO__%_EK!:DV_?^7^6M%J;S_
M_Q?]>[ZI(P``\`$``/#]`P"1\U,!J530.]7S``"P<_I'^>(``+!"Y$?Y8T`.
MD2%@"9&`:G/X.OW_EX!J<_@$``#P\U-!J80@%Y']>\*HXP,$J@(``+`!``#P
M0L`JD2'@"9$%`(!2`OW_%Q\@`]7@``"P`/A'^430.]7B``"P0N1'^2,``/`!
M``#P8T`.D8!H8/@A8`F1(OW_%Q\@`]7]>[ZI#02$TOT#`)'S4P&I_V,MR_\#
M`OG@``"P`,!'^?,C`)$!`$#YX0\0^0$`@-+0_/^7XP,`*@0``/`"``#PX`,3
MJH1`"I%"8`J1(0""TL3\_Y<?!``Q8`8`5`!\0),?!$#QZ`4`5``"@M+T8R"+
MX0,4JN`#$ZH"`(+2R?S_E_,#`*H`!?@W``0`$0!\0)/4_/^7XP,`JF`$`+1S
M?D"3'P`4ZX(``%0``!.+GP(`ZX,#`%1_`!3KZ`(`5"``@M)_`@#KZ`(`5.`#
M`ZKA`Q2JX@,3JJO\_Y?C`P"J'V@S..```+``P$?YX@]0^0$`0/E"``'K`0"`
MTJ$!`%0-!(32_V,MB^`#`ZKS4T&I_7O"J,`#7]:``A.+?P``ZP+]_U0`?2#4
M`P"`TN[__Q?!_/^7M/__%_U[NZD-$H+2_0,`D?-3`:GU6P*I_V,MR_\#`OGB
M``"P0L!'^?4#`*KS`P&JX1,`D4``0/G@1PCY``"`T@```/``P`J1,O[_E_0#
M`*KA!8!2X`,5JC+]_Y=@`@"TX0,5J@```/````N1Z?[_E^`#%:KA``"P(<!'
M^>-'2/DB`$#Y8P`"ZP(`@-+A#0!4#1*"TO]C+8OS4T&I]5M"J?U[Q:C``U_6
MX`,3JMG\_Y<6``#PP4(+D<[\_Y?S`P"J`/W_M/=C"/GW(P*1^&<(^1@``/`8
M@PN1^6L(^1D``/`Y8PN1^F\(^6`"0#F`!@`TM```M.$#$ZK@`Q2JT?S_EZ`$
M`#3@`Q.J_OS_EP($`-'Z`P"J8@("BW\"`NNC``!4"@``%%_T'SA_`@+K@```
M5$``0#D?O`!Q8/__5.`#$ZKP_/^7^@,`JN`#%:KM_/^7```:BP`$`)$?_#_Q
M:`(`5.,#$ZKE`Q6JY`,9JN(#&*K@`Q>J`0""TB[\_Y<`!``1'P1`<<D"`%0`
M?2#4@`9`.>`!`#7!0@N1``"`TI7\_Y?S`P"J(/K_M?=C2/GX9TCY^6M(^?IO
M2/FJ__\7]`,`M(`"0#D?N`!Q(/[_5!,``/`Z`(#2<Z(*D=S__Q?A(P"1X`,7
MJJO\_Y=@_?\UX!M`N0`,%!(?($!QX?S_5.`#%ZHA`(!2J_S_EV#\_S7A`Q>J
M````\```"Y%^_O^7X`,7JGS\_Y?W8TCY^&=(^?EK2/GZ;TCYD/__%Q,``/`Z
M`(#2<Z(*D<'__Q?W8PCY^&<(^?EK"/GZ;PCY*OS_EQ\@`]7]>[ZIX06`4OT#
M`)'S"P#Y\P,`JBO\_Y<?``#Q8`:`FO,+0/G]>\*H8OS_%Q\@`]7]>[ZI#0*"
MTOT#`)'_8RW+_P,"^>$``+`AP$?Y(@!`^>('"/D"`(#20`8`M/,3"/GT%PCY
M]`,`J@$`0#EA!0`TC/S_EP`$`)$?!$#Q"`<`5.$#%*KS(P"1X`,3JL7[_Y?@
M`Q.J@_S_EP`$`-%@`@"+'P`3ZZ@``%0'```4'_0?.!\`$^N```!4`0!`.3^\
M`'%@__]4X`,3JN$%@%+]^_^7H`0`M!\`$^OH`P!4X`,3JC3\_Y?A``"P(<!'
M^>,'2/DB`$#Y8P`"ZP(`@-+!!`!4\Q-(^0T"@M+T%TCY_V,MB_U[PJC``U_6
M\Q-(^?072/G@``"P`,!'^>('2/D!`$#Y0@`!ZP$`@-(!`P!4````\`"@"I$-
M`H+2_V,MB_U[PJ@8_/\7'P``.>'__Q<``(#2X?__%^```+``P$?YX@=(^0$`
M0/E"``'K`0"`TL$``%3S$TCY````\/072/D`H`J1[?__%\/[_Y?S$PCY]!<(
M^<#[_Y?_@P'1X```L`#`1_G]>P&I_4,`D?-3`JD4``#P\Q,`D?5;`ZF4H@N1
M]V,$J?DK`/GU``"PM=9'^0$`0/GA!P#Y`0"`TN$#$ZK@`Q2J,/W_E^`!`+2B
M`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#
M%*HB_?^78/[_M?4``+"UUD?Y%```\)3B"Y'A`Q.JX`,4JAK]_Y?@`0"TH@)`
M^>,'@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q2J
M#/W_EV#^_[7U``"PM=9'^10``/"4`@R1X0,3JN`#%*H$_?^7X`$`M*("0/GC
M!X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,4JO;\
M_Y=@_O^U]0``L+761_D4``#PE$(,D>$#$ZK@`Q2J[OS_E^`!`+2B`D#YXP>`
MN4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%*K@_/^7
M8/[_M?8``+#6UD?Y%```\)5B#)'A`Q.JX`,5JMC\_Y?@`0"TP@)`^>,'@+E`
M#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q6JROS_EV#^
M_[7V``"PUM9'^14``/"UH@R1X0,3JN`#%:K"_/^7X`$`M,("0/GC!X"Y0`P#
MBP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,5JK3\_Y=@_O^U
M]P``L/?61_D5``#PML(*D>$#$ZK@`Q:JK/S_E^`!`+3B`D#YXP>`N4`,`XL!
M!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%JJ>_/^78/[_M?@`
M`+`8UT?Y%@``\-?B#)'A`Q.JX`,7JI;\_Y?@`0"T`@-`^>,'@+E`#`.+`01`
M^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q>JB/S_EV#^_[7Y``"P
M.=='^1<``/#X(@V1X0,3JN`#&*J`_/^7X`$`M"(#0/GC!X"Y0`P#BP$$0/E!
M>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,8JG+\_Y=@_O^U^0``L#G7
M1_D8``#P&&,-D>$#$ZK@`QBJ:OS_E^`!`+0B`T#YXP>`N4`,`XL!!$#Y07@C
M^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#&*I<_/^78/[_M?D``+`YUT?Y
M&```\!@#"Y'A`Q.JX`,8JE3\_Y?@`0"T(@-`^>,'@+E`#`.+`01`^4%X(_CA
M_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QBJ1OS_EV#^_[7A`Q.J````T`"@
M#9%!_/^7X0,`JF```+3@(@V1_?S_E^$#$ZH```#0```.D3G\_Y?A`P"J@```
MM````-``8`Z1]/S_E^$#$ZH```#0`*`.D3#\_Y?A`P"J@`(`M*#""I'L_/^7
MX```D`#`1_GB!T#Y`0!`^4(``>L!`(#2@0(`5/U[0:F`8@R1\U-"J0$``-#U
M6T.I(4`/D?=C1*GY*T#Y_X,!D=O\_Q?A`Q.J````T`#@#I$7_/^7X0,`JD#]
M_[3`X@R1T_S_E^?__Q>-^O^7_X,`T0```-#B``"00L!'^>$3`)']>P&I_4,`
MD0#@#)%#`$#YXP<`^0,`@-(%_/^7X`$`M```0#D?P`!Q!!A`>N`'GQKA``"0
M(<!'^>,'0/DB`$#Y8P`"ZP(`@-+!``!4_7M!J?^#`)'``U_6``"`4O7__Q=O
M^O^7'R`#U1\@`]7_@P31[`:`$ND``)`IP4?Y[8,#D?U[!:G]0P&1ZP^`$NH`
M`)!*]4?YX!N`/>@#`)'A'X`]XB.`/>,G@#WD*X`]Y2^`/>8S@#WG-X`]X8L.
MJ>$#`*KB`PBJXY,/J>6;$*GGCP#Y0`%`^2,!0/GC)P#Y`P"`TN.#!)'CCP*I
MXZ,`D>T?`/GL+P@I8`1`K0`%`*WL^O^7X!^`4KKZ_Y<?(`/5_7N\J?T#`)'S
M4P&I]5L"J?<;`/G_0T#1_P,"^?]#`-'_`P+YX0``D"'`1_GC0T"1]`,`*D(`
M@%(D`$#Y9`0`^00`@-(!`(#2+OK_EQ,$`-'@`Q/K83Y`D@`\0)(@1(#:<P(`
MZV0&`%05`8#2]@,`D34`H/+W``"PX0,3JN`#%"H"`(!2'_K_EQ\$`+'`!0!4
MX@,5JN$#%JK@`Q0J1?K_EQ\$`#&@!`!4`'Q`DQ\<`/&I`P!4`"``T<`"`*NC
M``!4&0``%``$`-$?`!;KPP(`5`(`0/GA!D#Y7P`!ZT'__U0``!;+```3B^$`
M`)`AP$?YXT-`D60$0/DB`$#YA``"ZP(`@-)A`@!4_T,`D?]#0)'S4T&I]5M"
MJ?<;0/G]>\2HP`-?UG-"0-%_0D"Q8?K_5```@)+M__\7````T`"@#Y&(__^7
M````T`!@#Y&%__^7\/G_E_U[OZG]`P"1T?G_ET#Z_Y=```"T``!`^?U[P:C`
M`U_6_P,!T>$``)`AP$?Y_7L!J?U#`)'S4P*I]`,`JO5;`ZD5``#0MN(/D2(`
M0/GB!P#Y`@"`TN`#%JKA$P"17/O_EX```+0!`$`Y\P,`JN$!`#7@``"0`,!'
M^>('0/D!`$#Y0@`!ZP$`@-(A!@!4X0,4JJ#B#Y']>T&I\U-"J?5;0ZG_`P&1
M"OS_%^$#%*KH^?^7H`$`M.```)``P$?YX@=`^0$`0/E"``'K`0"`T@$$`%3]
M>T&I\U-"J?5;0ZG_`P&1P`-?UN`#%*HU^O^7]0,`JN`#$ZHR^O^7H`(`BP`(
M`)&;^?^7Y`,3JN(#%*KS`P"J`P``T`$``-!C0`N1(8`+D0/Z_Y?@``"0`,!'
M^>('0/D!`$#Y0@`!ZP$`@-*!``!4X0,3JN`#%JK3__\7G/G_E_]#!M'A``"P
M(2``D>(#`9$DH`"1_7L3J?W#!)'C``"08\!'^?-3%*GSHP"1*"1!J?5;%:GU
M`P"J)IQ%J?=C%JGX0P"1@0A`K6``0/G@EP#Y``"`TH`(P#WT,P"1)!!`^18`
M`-`C-$#YP,(*D>$#%*I!"`"MZ"<!J6,*`/D$"P#Y0`B`/>:?`JG]^O^7@```
MM`$`0#GW`P"J`10`-?EK%ZE7^?^7QOG_EV`.`+09`$#Y.0X`M.`#&:KM^?^7
M`/A_TP`$`)%6^?^7\P,`JB(#0#GW`P"J0@$`-!H``-!:0Q"1'R`#U>`#$ZKA
M`QJJO/G_EW,*`)$B'T`X8O__-0```-#Y(P&1`&`.D0,``!0@AT#XH`$`M.$#
M%*K9^O^7\P,`JF#__[0!`$`Y(?__-!'[_Y?@_O\TX`,3JI'Y_Y?S`P"J8`$`
MM1,#0/DS`0"T8`)`.0`+`#3@`Q.J!OO_E^`)`#43!T#Y&",`D3/__[7@`Q.J
MO_G_E_@#`*K@`Q>JO/G_EQD#``LY$Q`1&@``T#E_0)/@`QFJ(OG_E^4#%ZKB
M`Q.J0V,+D00``-"$8!"1^`,`J@$``-`A@!"1B?G_E^`#&*H!.(!2POG_EQ\$
M`#&A``!4E_G_EP0`0+F?1`!QP0@`5.'#`9'@`QBJ0?G_E_,#`"J@```UX(-`
MN0`,%!(?$$!Q0`8`5.```)``]$?Y`0``T*("0/GC`QBJ``!`^2'`$9$C^?^7
M%P"`TN```)``P$?YXI=`^0$`0/E"``'K`0"`TD$=`%3]>U.IX`,7JO-35*GU
M6U6I]V-6J?EK5ZG_0P:1P`-?UD;Y_Y?Y`P"J8`(`M7,B`)%@`D#YX`8`M.$#
M%*I_^O^78/__M`$`0#G!_O\U<R(`D?C__Q?@`Q.J&",`D3?Y_Y?S`P"JX/3_
MM+#__Q<3`(#2KO__%VWY_Y<`^'_3``0`D8#__Q?WBT"YS/C_E_\"`&N!^?]4
MX(-`N?O#`/D`(``2'P`'<6`$`%3[PT#YQ?__%^```)``]$?YXP,8JJ("0/D!
M``#0``!`^2'`$)'G^/^7Q/__%^[^_Y?@``"0`,!'^>*70/D!`$#Y0@`!ZP$`
M@-+A%0!4_7M3J>`#%ZKS4U2I]5M5J?=C5JG_0P:1"_G_%Z`!@-*Q^/^7&0``
MT/,#`*HY(Q"1]P,`JF(*@%):__\7X`,9JJGX_Y?A`Q2J]P,`J@```-``(!.1
M//K_E^$#`*J@"@"TH`)`^?7[_Y?[`P"J(`H`M.`#&ZHP^?^7^0,`JA\,`''M
M`0!4`'Q`DP$``-``$`#1(4`3D6`#`(OW^/^7``$`-3\3`'%`#@!4.1<`46#+
M>3@?O`!QP`T`5!\@`]7A`Q2J%```T(#B#)$?^O^7H```M```0#D?P`!Q!!A`
M>L$``%3@`QNJ`0"`4A?Y_Y?U`P`J0`8`-8#B#)$!``#0(4`/D='Z_Y=:8PN1
M%0``T+4B%Y$9``#06/C_ESE#%)'D`P`JXP,:JN4#%:KB`QBJX`,7J@$``-`A
M`!21V_C_EP\``!3M^/^7``!`N1]$`'$!`@!42?C_EW,&`!'D`P`JY0,3*N8#
M%:KC`QJJX@,8JN$#&:K@`Q>JS/C_E^`#%ZH!.(!2!?G_EQ\$`#'`_?]4X`,8
MJA'Y_Y?A`Q>JP,(*D:KZ_Y?@`Q>J??[_E_O#0/E1__\7NP)`^:___Q<;_O^7
M^0,`JJ#Y_[<!*`#1`@"`4N`#%2K[PP.15/C_E^`#%2KA`QNJP@"`TGSX_Y<?
M&`#QP04`5.'S0+D`8(A2(&BH<C\``&NA]_]480M`>0"IB%(_``!K(??_5"'+
M`-$"`(!2X`,5*O/C`Y%`^/^7X`,5*N$#$ZH"!8#2:/C_EQ^@`/%!`P!4Y`,3
MJD-C"Y'B`QBJX`,7J@4``-`!``#0I2`7D2'`$Y'_@P0YD/C_E\G__Q>U!D#Y
M=?+_M.`#%:JO^/^7'PP`\>GQ_U0`$`#1`0``T*`"`(LA8!.1>/C_EQ\``'%[
M$Y6:A___%P```-``@!.1MOW_E_O#`/D@^/^7^6L7J?O#`/D=^/^7_T,!T0``
M`-#B``"00L!'^0!@#)']>P&I_4,`D?-3`JE4T#O5\P``D'/Z1_GU6P.I]A,`
MD>$#%JKW8P2IE6IS^$,`0/GC!P#Y`P"`TJ+"0CFBQ@(YB_G_EX```+0!`$`Y
M/\0`<<`*`%1#_/^7E6IS^.`#%:H!``#08P"`4B&@%)$B`(!26_C_E_4#`*I@
M`0"TH0I`^0(``-"`:G/X0L`4D2$`0/G_]_^7H`I`^0$`0/D@#$"Y``JP-X!J
M<_@!``#08P"`4B'@%)$B`(!2]P``L$CX_Y?U`P"J8`$`M.$#%JH```#0```+
MD6;Y_Y?B`P"JP`8`M*$*0/F`:G/X(0!`^>CW_Y>5:G/X(@"`4@$``-`A`!61
MX`,5JA;X_Y<"``#0X0,`JD)@%9'@`Q6JW??_EX)J<_CSX@*1X0,6J@```-``
MP`J17\0".4[Y_Y=@"@#Y@`(`M`$X@%)>^/^7`00`$3\$`'$$B%%ZX04`5.``
M`)``P$?YX@=`^0$`0/E"``'K`0"`TN$$`%3]>T&I\U-"J?5;0ZGW8T2I_T,!
MD<`#7]9@!D#Y&/[_EV`*`/E`_?^U````T`"`%9%R]_^7``1`.8#U_S2I__\7
MGOK_E_@#`*J``0"TH0I`^>(#`*J`:G/X(0!`^:_W_Y?@`QBJ2?C_E\7__Q>`
M:G/X=O?_EZ___Q?@X@*1H0I`^0`$0/DA`$#Y`@!`^8!J<_BB]_^7NO__%Y3W
M_Y?WX@*1XP,`*@```-``(!:1X8I`J2$`0/E1]_^7_\,`T>$``)`AP$?Y_7L!
MJ?U#`)'S4P*I\P,`J@```-`B`$#YX@<`^0(`@-(`X`R1X1,`D0/Y_Y<@`0"T
M``!`.1_``'$$&$!ZX`>?&G\"`/'A!Y\:/P``:H$!`%3@``"0`,!'^>('0/D!
M`$#Y0@`!ZP$`@-(!!`!4_7M!J?-30JG_PP"1P`-?UF`"0#F`_O\TX`,3JDO[
M_Y?A!8!2]`,`JFSW_Y<?``#Q@`:`FJ7W_Y<!``#0@@"`TB%@$)&)]_^7X/S_
M->```)``P$?YX@=`^0$`0/E"``'K`0"`TL$``%3]>T&IX`,3JO-30JG_PP"1
M./G_%T_W_Y<?(`/5'R`#U?U[OZD!X`"1!.`!D>,``)!CP$?Y_0,`D5'D`&__
M0PK1\.4`;^(#`)&'Y`!O90!`^>5'`?D%`(#2XP,"JB,`0&TB!,$\8SB`#D$$
M8&]`!%AO8P@@+D($2&\F5%A/`!PQ3F2D("\A5$A/PQPP3@`<HDXA'"=.`!RC
M3@4<H4YDC)],GP`!Z\']_U3PGT"M0J`)D>:/0:WAHP&1Y9-"K>$?P#WQY0!O
M'R`#U2*`V3PA0`"1(`#?/``<(FX`'"-N`!PP;O`<IT[''*9.9ARC3@)404\`
M!&%OHQRE3H4<I$XD'*%.0!R@3@$<,4XA@(`\/P`"Z\']_U0'*$"I)#./T@@D
M0:E$4*ORY3]`J2-TG=+B_%O3[/Q"TT(4!ZJ,>0>J(0$(RB/;K?(A``J*(0`)
MRJ4`!(LB0"*+0?U"TPL00/DA>`JJ+7Q`DD(`!8NE`0C*0@`+"^9#0:FE``>*
MI0`(RN\!!(M._%O3I0`)B\X5`JHA``S*I0`/BR$``HJE``X+3_Q"TR$`#<KB
M>0*JQ@`$BZ[\6],A``B+SA4%JB$`!HN&`0+*(0`."XQ]0)+&``6*KOQ"T\8`
M#,H0`@2+Q@`-BR_\6]/->06J[Q4!JNX30/E%``W*Q@`0BT)\0)+&``\+I0`!
MBJ4``LHP_$+3S@$$BZ4`#(O/_%O3#'H!JN\5!JJE``Z+I0`/"Z$!#,K/_$+3
M(0`&BN9Y!JJM?4"2[K]"J2$`#<HA``*+L/Q"T\(!!(NN_%O3(0`"BX(!!LI"
M``6*C'U`DLX5!:I"``S*+@`."P5Z!:KA`02+0@`-BT(``8O!``7*T'Q`DB$`
M#HHA`!#*S?U;TR$`#(NM%0ZJ[[-#J4T`#0O&_4+3SG@.JJ9\0)+B`02+K_U;
MTR$``HNB``[*[Q4-JD(`#8HO``\+I?U"TT(`!LJ!`02+I7@-JD(`$(M"``&+
M[/U;T\$!!<KP_4+3C!4/JB$`#XH/>@^J3``,"^W#1*G.?4"2(0`.RB$`!HN&
M_5O3QA0,JJ(!!(L0`@2+(0`"BZ(`#\HM``8+I7Q`DD(`#(J&_4+30@`%RL9X
M#*JA_5O30@`.BT(`$(LL%`VJL/U"T^$!!LHA``V*#7H-JN[#1:E,``P+[WU`
MDB$`#\HA``6+A?U;TZ44#*K"`02+$`($BR$``HO"``W*+@`%"\9\0))"``R*
MA?U"TT(`!LJE>`RJP?U;TT(`#XM"`!"++!0.JM#]0M.A`07*(0`.B@YZ#JKO
MPT:I3``,"ZU]0)(A``W*(0`&BX;]6]/&%`RJX@$$BQ`"!(LA``*+H@`.RB\`
M!@NE?$"20@`,BH;]0M-"``7*QG@,JN']6]-"``V+0@`0BRP4#ZKP_4+3P0$&
MRB$`#XH/>@^J[<-'J4P`#`O.?4"2(0`.RB$`!8N%_5O3I10,JJ(!!(L0`@2+
M(0`"B\(`#\HM``4+A?U"TZ5X#*I"``R*H?U;T\9\0)(L%`VJX0$%RB$`#8KO
M?4"20@`&RB$`#\I"``Z+(0`&B^Z;2*E"`!"+3``,"[#]0M,->@VJD/U"T\(!
M!(N._5O3(0`"B\X5#*JB``W*+@`."Z5\0))"``R*0@`%R@QZ#*K!``2+0@`/
MB\;]6]-"``&+[T]`^:$!#,K&%`ZJK7U`DM(``@LA``Z*(0`-RN0!!(LA``6+
MT/U"TT7^6],.>@ZJ[U-`^2$`!(NE%!*J1D`FB[```0N$`0[*A``&2N(!`XN$
M``V+!OY;TTW^0M.$``*+XE=`^;)Y$JK&%!"J)4`EB\\`!`O!`1+*)0`%2D$`
M`XNB0"R+#/Y"T^7]6].->1"J0@`!BZ44#ZKA6T#YL0`""X9`)HM$`@W*A``&
M2NS]0M,F``.+@4`NBR3^6]./>0^J(0`&BX04$:KF7T#YD``!"T5`)8NB`0_*
M10`%2B[^0M/1>1&JK$`RB\(``XL%_EO3YF-`^8(!`HNE%!"J)$`DB^$!$<JN
M``(+)``$2@S^0M/!``.+AD`MBY!Y$*K!``&+YF=`^<3]6]-%0"6+A!0.JB("
M$,J-``$+0@`%2L8``XM"0"^+S/U"TXYY#JI"``:+YFM`^:7]6].E%`VJ)$`D
MBP$"#LJO``(+(0`$2JS]0M.->0VJQ@`#BR%`,8OD_5O3(0`&BT5`)8OF;T#Y
MP@$-RH04#ZI%``5*D0`!"ZQ`,(OP_4+3P@`#B^9S0/D/>@^J)?Y;TR1`)(NA
M`0_*@@$"BZ44$:HD``1*L``""\$``XLL_D+3AD`NBXQY$:K!``&+YG=`^45`
M)8L$_EO3X@$,RH04$*I"``5*C@`!"\8``XM"0"V+#?Y"T_%[0/E"``:+IGD0
MJB1`)(O%_5O3@0$&RJ44#JHA``1*K0`""S`"`XLA0"^+S_U"TR$`$(ON>0ZJ
M\']`^:3]6].$%`VJ14`EB[']0M/"``[*CP`!"RUZ#:I%``5*`@(#B_"#0/DD
M0"2+P0$-RJQ`+(LD``1*Y?U;TZ44#ZJ&0":+\?U"TP$"`XO!``&+@@$"BR9Z
M#ZJL``(+14`EBZ(!!LI"``5*A/U;TT)`+HN$%`RJ\+M0J9']0M./``$++'H,
MJB1`)(O!``S*Y?U;TR$`!$KQ_4+3I10/JA`"`XLO>@^J0@`0BR%`+8OMQU&I
ML``""\X!`XM%0"6+!/Y;TR$`#HN$%!"J@@$/RHX``0M"``5*0D`FBZ4!`XL-
M_D+310`%B\;]6].B>1"JQA0.JB1`)(OA`0+*S0`%"R0`!$HA`@.+A$`LB]']
M0M/PET#YA``!BZS]6],A>@ZJC!4-JJ9`)HM%``'*C@$$"Z4`!DH0`@.+I4`O
MBZ_]0M/O>0VJI0`0B_";0/G&_5O3QA0.JHQ`+(LD``_*S0`%"XP`#$K1_4+3
M!`(#BX)!(HNP_5O30@`$BR1Z#JJF0":+[)]`^1`6#:KE`03*0@`0"Z4`!DJN
M_4+3H4`AB\5Y#:J&`0.+3OQ"TXP`!:I#_%O38Q0"JHP!`HK">0*J(0`&B^T[
M5*DA``,+HP`$"H:;E]*,`0.J9N.Q\H-!+XLO_$+3K`$&BRW\6].M%0&J8P`,
MBZP``JIC``T+C`$!BDT`!0J,`0VJX7D!JLX!!HN$022+;?Q;TTP``:JM%0.J
MA``.BX0`#0N,`0.*+0`""F[\0M.,`0VJC?Q;TX5!)8O,>0.J[SM5J:,5!*HM
M``RJ[P$&B\X!!HNE``^+C_Q"TZ,``PNE`02*C0$!"J4`#:IM_%O3I4`BB^)Y
M!*JM%0.JA`$"JJ4`#HN$``.*I0`-"TT`#`J$``VJ;?Q"TX1`(8NA>0.J[S=6
MJ:[\6]/.%06J0P`!JF,`!8KO`0:+K0$&BX0`#XNO_$+3A``."RX``@IC``ZJ
MY7D%JF-`+(N._%O3SA4$JBP`!:IC``V+C`$$BNV[0/EC``X+K@`!"H_\0M.,
M`0ZJY'D$JH)!(HMN_%O3K`$&B\X5`ZKMOT#Y0@`,BZP`!*I"``X+C`$#BHX`
M!0J,`0ZJ;_Q"T^-Y`ZJM`0:+@4$ABT[\6]/.%0*JC``#JB$`#8N,`0**(0`.
M"VX`!`J,`0ZJ3OQ"T\)Y`JJ%026+[3M8J2_\0M.L`0:++?Q;TZT5`:JE``R+
M;``"JJ4`#0N,`0&*30`#"HP!#:KA>0&JS@$&BX1!)(NM_%O33``!JJT5!:J$
M``Z+A``-"XP!!8HM``(*KOQ"TXP!#:J-_%O3@T$CB\QY!:KO.UFIK14$JB4`
M#*JE``2*[P$&B\X!!HMC``^+C_Q"TV,`#0N-`0$*I0`-JN1Y!*JB0"*+;?Q;
MTZT5`ZJ%`02J0@`.BZ4``XI"``T+C0`,"J4`#:IM_$+3H4`ABZ5Y`ZKO-UJI
M3OQ;T\X5`JJ#``6J8P`"BN\!!HNM`0:+(0`/BZ\`!`HA``X+8P`/JD[\0M-L
M0"R+PGD"JB/\6].,`0V+8Q0!JJT``JHO_$+3@P$#"ZP!`8KA>0&J30`%"NX_
M6ZF,`0VJA$$DBVW\6].M%0.JS`$&BRX``@J$``R+3``!JH0`#0N,`0.*C`$.
MJFW\0M.M>0.J[P$&BX5!)8N._%O3[.-`^:,`#XO.%02J)0`-JF,`#@NE``2*
MK@$!"H_\0M.E``ZJ;OQ;TZ)`(HN%`0:+Y'D$JLX5`ZI"``6+I0$$JD(`#@MN
M_$+3I0`#BL-Y`ZKLNURICP`-"J4`#ZI/_$+3I4`ABT'\6],A%`*JC`$&BZ4`
M#(N,``.JI0`!"XP!`HIA``0*XGD"JHP!`:I0``,*@4$MB\T!!HNL_%O3(0`-
MB^_O0/EM``*JC!4%JJT!!8J.`0$+K0$0JJ1!)(NP_$+3[0$&B\;]6]/O\T#Y
MA``-B\84#JH->@6JT0`$"RQ`+(M!``W*Q3J8TB$`#$I%3+GR(4`CB^P!!8O0
M_4+3(_Y;T^_W0/D.>@ZJ8Q01JB$`#(ML``$+AD`FBZ0!#LHC0".+A``&2N8!
M!8N"0"*++_Y"TX3]6]/Q>1&J0@`&BX04#*KF^T#YD@`""\$!$<I$0"2+(P`#
M2L$`!8MF0"V+C?U"TT/^6].P>0RJQ@`!BV,4$JKA_T#Y;P`&"R("$,I,_D+3
M0@`$2B0`!8M"0"Z+X?U;TXUY$JI$``2+X@-!^2$4#ZHN``0+PT`CBP8"#<KL
M_4+3PP`#2D8`!8MC0#&+POU;TX]Y#ZIC``:+Y@=!^4(4#JI1``,+@4`ABZ0!
M#\IB0"*+@0`!2L0`!8LL0#"+T/U"TR'^6],.>@ZJY@M!^80!!(LA%!&JXP$.
MRC``!`MB``)*+/Y"T\,`!8M&0"V+`OY;TXQY$:K#``.+Y@]!^4(4$*I-``,+
M@4`AB\0!#,H1_D+3@0`!2L8`!8LD0"^+H?U;T^\30?F$``:+(10-JB9Z$*IB
M0"*+,``$"X,!!LKO`06+8@`"2K']0M-#0"Z+`OY;T^X70?DM>@VJ8P`/BT(4
M$*I/``,+@4`AB\0`#<IB0"*+@0`!2L0!!8LL0"R+#OY"T^']6]/0>1"JA`$$
MBR$4#ZKL&T'Y,0`$"Z,!$,J!0"&+8@`"2H,!!8M&0":+[/U"TR+^6]./>0^J
MPP`#BT(4$:KF'T'Y3@`#"P0"#\IB0"*+@0`!2L8`!8LD0"V++?Y"T\']6].$
M``:+["-!^:9Y$:HA%`ZJXP$&RBT`!`MB``)*C`$%BT-`,(O0_4+3HOU;TPYZ
M#JIC``R+["=!^4(4#:I1``,+@4`AB\0`#LIB0"*+@0`!2H0!!8LL0"^+K_U"
MTR'^6]/M>0VJA`$$BR$4$:KL*T'Y,``$"\,!#<HO_D+38@`"2HP!!8M"0":+
M`_Y;TT8`#(MC%!"JXB]!^>QY$:J!0"&+;P`&"Z0!#,K#0".+A``!2D$`!8N$
M0"Z+XOU;TP[^0M.$``&+\3-!^<%Y$*I"%`^JA@$!RDX`!`O#``-*,`(%BV9`
M+8OQ_4+3P_U;T^TW0?EC%`ZJ+WH/JL8`$(MP``8+@D`BBR0`#\K&0".+A``"
M2J(!!8N,0"R+S?U"TP3^6].,`0*+XCM!^804$*JN>0ZJ@P`,"^T!#LKG0"^+
MK0$&2D8`!8NA02&+8OQ;TT(4`ZHA``:+[3]!^2$``@L"_D+3AD$DBT)X$*HD
M_%O3S`$"RH04`:J,`09*I@$%BV7\0M/&``>+HW@#JH0`#(O'``#PY\!'^2$`
M"@M"``D+Q0$+"X0`!@MC``@+!`0`J0,(`:D%$`#YXD=!^>$`0/E"``'K`0"`
MTH$``%3_0PJ1_7O!J,`#7]8?\_^7'R`#U1\@`]7]>[^I`!"`TOT#`)$%\_^7
M'Q@`^2(``+`A``"P'W@`N4'PP#TB``"P(NS`/4#TP#T"!`"M``B`/?U[P:C`
M`U_6_7N[J4)\0)/]`P"1\U,!J13@`)'U6P*I]0,"JO=C`ZGW`P&J^2,`^?D#
M`*H%C$*I`7A`N:0,`@N_``3K8Y2#FF)T0HL$B`*I(0,`-!,(@%)S`@%+?P(5
M:Q3@`)%STI4:@,(ABV)^0),?`!?K`@@`5`$``HOV`@*+_P(!Z\,$`%3A`Q>J
MO_+_ER%[0+EA`@$+(7L`N3\``7%A!0!4M0(32_<#%JK@`QFJEOO_E[_^`'%-
M`P!4\P,7JCCC`9'V`@&1#P``%'\"&.MC`@!4]P,6JF`&0*W@`QFJM0(!4=8"
M`9&`!@"M8`9!K7,"`9&`!@&MA/O_E[_^`'$-`0!4GP(3ZR/^_U3W`Q:J2?[_
M5)\"%NL"_O]4`'T@U*)^0).?`A?KXP$`5(D``%3@`@*+GP(`ZR/__U3A`Q>J
MX`,4JI'R_Y<U>P"Y\U-!J?5;0JGW8T.I^2-`^?U[Q:C``U_6@`("B_\"`.N"
M_O]4`'T@U/8"`HN)^/]4'P`6ZT+X_U0`?2#4_7N\J>(/@!+]`P"1\U,!J?0#
M`*KS`P&J]5L"J3;@`)'H&P#]-11`^2@80/V@(@-3`00`$<+*(#@@?$"3/^``
M<6T+`%0""(!20@`!2P$`@%+``@"+0GQ`D][R_Y?@`Q.J2/O_E]\:`/D`!`!/
MP`(`K<`*@#T%!7!_``5H?P0%>'^A`F>>X`,3JB,$:'\B!'!_H`0#;B$$>'^`
M!`5N``4';F`$"6Y`!`MN(`0-;J`>#TY@.@#],_O_EV$"0/G@`Q.J(?Q8TX$"
M`#EA`D#Y(?Q0TX$&`#EA`D#Y(?Q(TX$*`#EA`D#Y@0X`.6$&0/DA_%C3@1(`
M.6$&0/DA_%#3@18`.6$&0/DA_$C3@1H`.6$&0/F!'@`Y80I`^2'\6-.!(@`Y
M80I`^2'\4-.!)@`Y80I`^2'\2-.!*@`Y80I`^8$N`#EA#D#Y(?Q8TX$R`#EA
M#D#Y(?Q0TX$V`#EA#D#Y(?Q(TX$Z`#EA#D#Y@3X`.6$20/DA_%C3@4(`.6$2
M0/DA_%#3@48`.6$20/DA_$C3@4H`.6$20/F!3@`Y\U-!J?5;0JGH&T#]_7O$
MJ.KR_Q<"!X!20@`!2\`"`(L!`(!20GQ`DX3R_Y>L__\7_7N_J?T#`)']>\&H
MP`-?U@``````````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O
M)6DO)7,``````"X`````````4$%27U1%35```````````%!!4E]04D]'3D%-
M10`````Z`````````"\`````````)7,E<R5S``!015),-4Q)0@``````````
M4$523$Q)0@!015),-4]05```````````4$523$E/``!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140``````%!!4E]#3$5!3@````````!005)?1$5"54<`
M````````4$%27T-!0TA%`````````%!!4E]'3$]"04Q?1$5"54<`````````
M`%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]435!$25(```````!005)?
M1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````,0````````!L
M<V5E:R!F86EL960`````<F5A9"!F86EL960``````$Q$7TQ)0E)!4EE?4$%4
M2`!365-414T``"4P,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H```````!0051(`````'!A<FP`````+G!A<@````!S:&]R="!R
M96%D````````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S
M=&5M<"TE=2TE=25S```````````8`````````'!E<FP`````,`````````!0
M05(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V,0```%5N86)L92!T;R!C<F5A
M=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M```````````M90```````"TM````````55-%4@````!54T523D%-10``````
M````5$U01$E2``!414U01$E2`%1%35``````5$U0```````O=&UP`````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C
M:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A
M8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P
M-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H
M=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@
M)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O
M<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU
M;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R
M:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@
M)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^
M)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S
M*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O
M;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@
M34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I
M.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA
M9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I
M=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?
M1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#
M04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@
M;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M
M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O
M9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO
M=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D
M;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@[
M"FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN
M72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@
M=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D
M9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T
M<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D
M<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@
M<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*
M:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A
M<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q
M("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V
M:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D
M,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I
M('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I
M('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]
M("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL
M)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@
M*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q
M6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E
M<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF
M("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM
M>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N
M;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC
M;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB
M:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F
M:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A
M9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B
M.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D
M=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF
M("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*
M?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@
M/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^
M861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D
M8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<
M,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F
M9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E
M(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D
M(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F
M86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(
M*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@
M*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP
M+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@
M>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER
M(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K
M("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H
M*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG
M=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D
M8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H
M95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D
M8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%2
M7T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H
M95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM
M>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I
M;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC``````````!#04-(10``
M```````````!(T5G`````(FKS>\`````_MRZF`````!V5#(0`````/#ATL,`
M```````````````!&P,[]````!T```#PB?__(`8``$",__\,`0``<(S__R`!
M``"PC/__-`$``!"-__]8`0``4(W__W@!``!$CO__X`$``.".__\(`@``4)#_
M_U@"``!TDO__K`(``."2___0`@``$)/__^0"``!`E/__%`,``$24__\H`P``
MH);__Y`#``#0EO__M`,``$28__\0!```$)W__TP$``"0G?__<`0``#">__^,
M!```A)___]`$``"DG___\`0``-2@__\L!0``T*;__[0%```0J?__[`4``!"J
M__]0!@``T+K__WP&```0N___G`8``)"\___8!@```````!```````````7I2
M``1X'@$;#!\`$````!@````LB___,``````````0````+````$B+__\\````
M`````"````!`````=(O__V``````00X@G02>`T*3`E3>W=,.`````!P```!D
M````L(O__S0`````1`X0G0*>`4?>W0X`````9````(0```#0B___]`````!!
M#D"=")X'0I,&E`5"F`&7`D:6`Y4$5M;50=C70][=T]0.`$$.0),&E`65!)8#
MEP*8`9T(G@=/UM5!V-=!WMW3U`X`00Y`DP:4!9T(G@="EP*8`4'8UP`D````
M[````%R,__^<`````$$.L`%$G02>`T*3`E8*W=[3#@!!"P``3````!0!``#0
MC/__;`$```!!#L`!0YT&G@5&E`.3!$34TTG=W@X`00[``9,$E`.=!IX%098!
ME0)T"M330=;500M)T]35UD&4`Y,$098!E0)0````9`$``/"-__\D`@```$$.
M8$&="IX)0I,(E`=-E0:6!9<$F`-_"MW>U]C5UM/4#@!!"TF:`9D"70K:V4$+
M2-G:0ID"F@%#V=I!F@&9`D+:V0`@````N`$``,"/__]H`````$$.()T$G@-$
MDP*4`4[>W=/4#@`0````W`$```B0__\L`````````"P```#P`0``))#__S`!
M````00X@G02>`T0.P$"3`I0!?`H.($/>W=/4#@!!"P```!`````@`@``))'_
M_P0`````````9````#0"```4D?__6`(```!!#E"="IX)10[@(9,(E`>5!I8%
M7PH.4$/>W=76T]0.`$$+2)<$0I@#0YD"0YH!<0K70=A!V4':00M;"M=!V$'9
M0=I!"T37V-G:09<$09@#09D"09H!```@````G`(```B3__\L`````$$.()T$
MG@-#DP)&WMW3#@````!8````P`(``!23__]T`0```$$.()T$G@-##K`@2),"
M090!:`K30M1!#B!!WMT.`$$+0=-!U$L.($'>W0X`00ZP(),"E`&=!)X#3`K3
M0M1""T'3U$&3`D&4`0```#@````<`P``+)3__\P$````00Y@0YT*G@E"DPB4
M!T:5!I8%EP28`YD"`QP!"MW>V=?8U=;3U`X`00L``"````!8`P``O)C__W@`
M````00X@19T"G@%4"MW>#@!!"P```!@```!\`P``&)G__YP`````00Z@`D6=
M&IX9``!`````F`,``)R9__]4`0```$$.0)T(G@=%#L"`!),&E`65!)8#EP)"
M#M"`!'L*#L"`!$$.0$3>W=?5UM/4#@!!"P```!P```#<`P``K)K__R``````
M00X0G0*>`4;>W0X`````.````/P#``"LFO__,`$```!!#D!#G0:>!4*3!)0#
M0I4"E@%9"MW>U=;3U`X`00M."MW>U=;3U`X`00L`A````#@$``"@F____`4`
M``!!#I`#19T,G@M$DPJ4"4.5")8'0Y<&F`58F@.9!`)O"MK90=W>U]C5UM/4
M#@!!"U^;`D3;2MG:3MW>U]C5UM/4#@!!#I`#DPJ4"94(E@>7!I@%F02:`YT,
MG@M(FP("7`K;00L"0-M!FP)!V=K;09H#F01!FP(``#0```#`!```%*'__T`"
M````00Y019T(G@="DP:4!425!)8#0Y<"F`$"6`K=WM?8U=;3U`X`00L`,```
M`/@$```<H___^`````!!#C!#G02>`T*3`I0!6PK=WM/4#@!!"UH*W=[3U`X`
M00L``"P````L!0``R(/__PP"````00Y@0YT&G@5(DP24`Y4"E@$"5@K=WM76
MT]0.`$$+`"@```!<!0``N*/__[@0````00X0G0*>`4<.H`4#(P0*#A!!WMT.
M`$$+````'````(@%``!,M/__0`````!!#A"=`IX!3M[=#@`````X````J`4`
M`&RT__^``0```$$.4)T*G@E#DPB4!T*5!I8%0I<$F`-"F0("3`K>W=G7V-76
MT]0.`$$+```T````Y`4``+"U___(`0```$$.0)T(G@=#DP:4!4.5!)8#0@5(
M`@)A"M[=U=;3U`9(#@!!"P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````/`@````````D"`````````!`````````/`"````````
M`0````````#[`@```````!T`````````400````````,`````````/`9````
M````#0`````````X4@```````!D`````````F/L!```````;``````````@`
M````````&@````````"@^P$``````!P`````````"`````````#U_O]O````
M`'@"````````!0````````!`#0````````8`````````:`,````````*````
M`````&\$````````"P`````````8`````````!4````````````````````#
M`````````(C]`0```````@````````"(!0```````!0`````````!P``````
M```7`````````&@4````````!P````````"P$0````````@`````````N`(`
M```````)`````````!@`````````'@`````````(`````````/O__V\`````
M`0``"`````#Y__]O`````!``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````&@``````
M```:`````````!H`````````&@`````````:`````````!H`````````&@``
M```````:`````````!H`````````&@`````````:`````````!H`````````
M&@`````````:`````````!H`````````&@`````````:`````````!H`````
M````&@`````````:`````````!H`````````&@`````````:`````````!H`
M````````&@`````````:`````````!H`````````&@`````````:````````
M`!H`````````&@`````````:`````````!H`````````&@`````````:````
M`````!H`````````&@`````````:`````````!H`````````&@`````````:
M`````````!H`````````&@`````````:`````````!H`````````&@``````
M```:`````````!H`````````&@`````````:`````````!H`````````&@``
M```````:`````````!H`````````&@`````````:`````````!H`````````
M&@`````````:````````J/L!````````````````````````````````````
M`````````````/`9````````````````````````````````````````````
M`````````````````-`=```````````````````X4@``````````````````
M`````````````````````````@``````"E!!4BYP;0H``````````!A6````
M````J%(``````````````````)A3````````^%4`````````5@````````A6
M````````$%8``````````````````.!5````````Z%4`````````````````
M`"!6````````1T-#.B`H06QP:6YE(#$S+C(N,5]G:70R,#(S,3`Q-"D@,3,N
M,BXQ(#(P,C,Q,#$T```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I
M;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD
M<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`
M+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````
M````````````````````````````````````````````````````````````
M````````"P````$````"`````````#@"````````.`(````````:````````
M`````````````0```````````````````!,````'`````@````````!4`@``
M`````%0"````````)`````````````````````0````````````````````F
M````]O__;P(`````````>`(```````!X`@```````.P`````````!```````
M```(````````````````````,`````L````"`````````&@#````````:`,`
M``````#8"0````````4````#````"``````````8`````````#@````#````
M`@````````!`#0```````$`-````````;P0```````````````````$`````
M``````````````!`````!`````(`````````L!$```````"P$0```````+@"
M````````!``````````(`````````!@`````````2@````0```!"````````
M`&@4````````:!0```````"(!0````````0````2````"``````````8````
M`````%0````!````!@````````#P&0```````/`9````````$```````````
M``````````0```````````````````!/`````0````8``````````!H`````
M````&@```````-`#```````````````````0````````````````````6@``
M``$````&`````````-`=````````T!T```````!H-```````````````````
M$````````````````````&`````!````!@`````````X4@```````#A2````
M````$`````````````````````0```````````````````!F`````0````(`
M````````4%(```````!04@```````)!!```````````````````0````````
M````````````;@````$````"`````````."3````````X),```````#T````
M````````````````!````````````````````'P````!`````@````````#8
ME````````-B4````````'`8```````````````````@`````````````````
M``"&````#@````,`````````F/L!``````"8^P````````@`````````````
M```````(``````````@`````````D@````\````#`````````*#[`0``````
MH/L````````(````````````````````"``````````(`````````)X````&
M`````P````````"H^P$``````*C[````````X`$````````%``````````@`
M````````$`````````"G`````0````,`````````B/T!``````"(_0``````
M`'@"```````````````````(``````````@`````````K`````$````#````
M`````````@`````````!``````"`````````````````````"```````````
M`````````+(````(`````P````````"```(``````(```0``````6```````
M``````````````@```````````````````"W`````0```#``````````````
M``````"```$``````#$````````````````````!``````````$`````````
M`0````,`````````````````````````L0`!``````#`````````````````
3`````0``````````````````````
